@@ -225,8 +225,10 @@ class grammarSemantics(object):
             if atom['range']:
                 low, high = map(int, atom['range'])
                 ports = ports + range(low, high + 1)
+        # sort and deduplicate all ports
+        ports = set(ports)
+        # create the smallest amount of port ranges possible
         atoms = []
-        """ compress the port numbers from a single line into ranges """
         for a, b in itertools.groupby(enumerate(ports), lambda(x, y): y - x):
             b = list(b)
             atoms.append(b[0][1] if b[0][1] == b[-1][1]
@@ -237,12 +239,13 @@ class grammarSemantics(object):
         return ast
 
     def port_range(self, ast):
-        low, high = map(int, ast)
+        low = 0 if ast[0] == "-" else int(ast[0])
+        high = 65535 if ast[1] == "-" else int(ast[1])
         if low > high:
             raise FailedSemantics('First port cannot be higher than second \
 port in a range expression')
             sys.exit(2)
-        return ast
+        return [low, high]
 
     def port_number(self, ast):
         port = int(ast)
